==> pf4-component-mapper-3.18.0.tgz: package/esm/switch/switch.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["label", "offText", "onText", "isRequired", "helperText", "meta", "validateOnMount", "description", "input", "isReadOnly", "isDisabled", "id", "FormGroupProps"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { Switch as Pf4Switch } from "@patternfly/react-core/dist/esm/components/Switch/Switch.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormGroup from '../form-group/form-group';
import IsRequired from '../is-required/is-required';

var Switch = function Switch(props) {
  var _useFieldApi = useFieldApi(_objectSpread(_objectSpread({}, props), {}, {
    type: 'checkbox'
  })),
      label = _useFieldApi.label,
      offText = _useFieldApi.offText,
      onText = _useFieldApi.onText,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      id = _useFieldApi.id,
      FormGroupProps = _useFieldApi.FormGroupProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  return /*#__PURE__*/React.createElement(FormGroup, {
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: true,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(Pf4Switch, _extends({}, rest, input, {
    id: id || input.name,
    isDisabled: isDisabled || isReadOnly,
    label: isRequired ? /*#__PURE__*/React.createElement(IsRequired, null, onText || label) : onText || label,
    labelOff: isRequired ? /*#__PURE__*/React.createElement(IsRequired, null, offText || label) : offText || label
  })));
};

Switch.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  isDisabled: PropTypes.bool,
  id: PropTypes.string,
  onText: PropTypes.node,
  offText: PropTypes.node,
  FormGroupProps: PropTypes.object
};
export default Switch;

==> pf4-component-mapper-3.23.0.tgz: package/esm/switch/switch.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["label", "offText", "onText", "isRequired", "helperText", "meta", "validateOnMount", "description", "input", "isReadOnly", "isDisabled", "id", "FormGroupProps"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { Switch as Pf4Switch } from "@patternfly/react-core/dist/dynamic/components/Switch";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormGroup from '../form-group/form-group';
import IsRequired from '../is-required/is-required';

var Switch = function Switch(props) {
  var _useFieldApi = useFieldApi(_objectSpread(_objectSpread({}, props), {}, {
    type: 'checkbox'
  })),
      label = _useFieldApi.label,
      offText = _useFieldApi.offText,
      onText = _useFieldApi.onText,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      id = _useFieldApi.id,
      FormGroupProps = _useFieldApi.FormGroupProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  return /*#__PURE__*/React.createElement(FormGroup, {
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: true,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(Pf4Switch, _extends({}, rest, input, {
    id: id || input.name,
    isDisabled: isDisabled || isReadOnly,
    label: isRequired ? /*#__PURE__*/React.createElement(IsRequired, null, onText || label) : onText || label,
    labelOff: isRequired ? /*#__PURE__*/React.createElement(IsRequired, null, offText || label) : offText || label
  })));
};

Switch.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  isDisabled: PropTypes.bool,
  id: PropTypes.string,
  onText: PropTypes.node,
  offText: PropTypes.node,
  FormGroupProps: PropTypes.object
};
export default Switch;
